\name{BACarray}
\alias{BACarray}
\title{Example CGH BAC Array Data}
\description{A list containing an example CGH BAC array data for package \code{clac}}

\format{
BACarray is a list of four components: 
\tabular{rl}{
NormalArray \tab  a numeric matrix consisting of 2270 rows and 3 columns \cr
DiseaseArray \tab a numeric matrix consisting of 2270 rows and 4 columns \cr 
chromosome  \tab  a numeric vector of length 2270\cr
nucposition  \tab a numeric vector of length 2270
}
}

\details{
In \code{NormalArray} and \code{DiseaseArray}, each column corresponds to
one CGH array, and each row corresponds to one gene/clone. The value of each entry is the log fluorescence
ratio resulted from the CGH experiment. The order of the genes/clones in the rows is the same as the order of the
genes/clones on the genome. \code{chromosome} and \code{nucposition} provide chromosome number and nucleotide 
position for each gene/clone.}

\references{
P. Wang, Y. Kim, J. Pollack, B. Narasimhan and R. Tibshirani, A method for calling gains and losses in array CGH data, Biostatistics (accepted for publication 4/5/2004), available at http://www-stat.stanford.edu/~wp57/CGH-Miner/
}

\usage{data(BACarray)}

\keyword{datasets}


\eof
\name{CLAC analysis for CGH-Miner}
\alias{clac.from.Excel}
\alias{clac.preparenormal.Excel}
\alias{clac.onetumorarray.Excel}
\alias{clac.finalsummary.Excel}
\alias{clac.PlotOneArray}
\alias{clac.PlotConsensus}

\title{R Functions for Excel Addin Packgage CGH-Miner}

\description{These functions are desinged to be called by Excel Addin package CGH-Miner to perform CLAC analysis.}
   
\usage{
clac.from.Excel(column.name, SampleID, Data, windowsize, FDR, log2trans, centerColumn, chromosomeOption)
clac.preparenormal.Excel(inputdata)
clac.onetumorarray.Excel(NormalResult, i)
clac.finalsummary.Excel(NormalResult, CLAC.result)
clac.PlotOneArray(inputdata, clac.result, Sample) 
clac.PlotConsensus(inputdata, clac.result, SampleIDPick)
}

\arguments{
    \item{column.name}{string vector, provides the column names in the spread sheet.}
    \item{SampleID}{string vector, provides the sample ID for each CGH array.}
    \item{Data}{numeric matrix, contains the data read in from the spread sheet.}
    \item{windowsiz}{enumeric value, specifying the window size to carry out the average smooth.}
    \item{FDR}{numeric value between 0 and 1, specifying the desired fianl FDR for CLAC analysis.}
    \item{log2trans}{boolean variable, if TRUE, a log2 transform will be performed on \code{Data}.}
    \item{centerColumn}{boolean variable, if TRUE, the columns of \code{Data} will be centered to zero.}
    \item{chromosomeOption}{boolean variable. If False, the chromosome arms will be considered seperately. If true, two chormosome arms of one chromosome would be dealed together.}
    \item{inputdata}{retruned object from function \code{clac.from.Excel}.}
    \item{NormalResult}{return object from function \code{clac.preparenormal.Excel}.}
    \item{CLAC.result}{numeric matrix. First row records the estimated FDR for each array; second row records the \code{alpha} value for each array; all left rows records the result of CLAC analysis for each array.}
    \item{Sample}{string variable, is the sample ID of one array.}
    \item{SampleIDPick}{string vector, is a subset of \code{SampleID}.}
}
    
\details{
    These functions are not to be used in RGui interface directly. For \code{clac} functions in R, please see \code{clac.preparenormal.R},
\code{clac.tumorarray.R, clac.PlotSingleArray.R, clac.PlotConsensus.R, clac.PlotAllArray.R}.
}

\references{
P. Wang, Y. Kim, J. Pollack, B. Narasimhan and R. Tibshirani, A method for calling gains and losses in array CGH data, Biostatistics (accepted for publication 4/5/2004), available at http://www-stat.stanford.edu/~wp57/CGH-Miner/
}

\keyword{internal}


\author{Pei Wang}




\eof
\name{clac.PlotAllArray.R}
\alias{clac.PlotAllArray.R}
\title{ A function to plot multiple arrays for CLAC result.}
\description{A function to plot multiple arrays for CLAC result.}
   
\usage{
clac.PlotAllArray.R(NormalResult, clac.result, ArrayName=NULL,centromere=NULL)
}
\arguments{
    \item{NormalResult}{result object of function \code{clac.preparenormal.R}}
    \item{clac.result}{result object of function clac.tumorarray.R}
    \item{ArrayName}{string vector, providing the name of each disease array in \code{clac.result}. The length should be the same as the total number of disease arrays.}
    \item{centromere}{numeric vector specifying the centromere positions. If missing, the default centromere value of human genome will be used.}
 }  
    
\details{
    \code{clac.PlotAllArray.R} plot multiple array for CLAC result.}

\value{
    No return value.
   }

\references{
P. Wang, Y. Kim, J. Pollack, B. Narasimhan and R. Tibshirani, A method for calling gains and losses in array CGH data, Biostatistics (accepted for publication 4/5/2004), available at http://www-stat.stanford.edu/~wp57/CGH-Miner/
}

\author{ Pei Wang}

\keyword{cluster}

\examples{
library(clac)
data(BACarray)
attach(BACarray)

############ prepare the normal reference arrays
NormalResult<-clac.preparenormal.R(DiseaseArray, NormalArray, Normal.Type=rep(0,3), chromosome.number=chromosome, nucleotide.position=nucposition, windowsize=5, targetFDR=0.01, chromosomeOption=FALSE)

############ clac on selected tumor arrays
clac.result<-clac.tumorarray.R(NormalResult, tumorarrayIndex=1:4)

############ Plot for the first arrays
i<-1
clac.PlotSingleArray.R(i, NormalResult, clac.result)
title(main=paste("CLAC Plot for the ", i ,"th BAC array; FDR=", round(clac.result$fdr[i],3), sep=""))

############ consensus plot
clac.PlotConsensus.R(clac.result, chromosome, nucposition,  1:4)
title(main="Consensus Plot for 4 BAC arrays")

############ Plot all arrays
clac.PlotAllArray.R(NormalResult, clac.result)
title(main="Plot for all 4 arrays")
}

\eof
\name{clac.PlotConsensus.R}
\alias{clac.PlotConsensus.R}
\title{ A function to make consensus plot for CLAC result.}
\description{A function to make consensus plot for CLAC result.}
   
\usage{
clac.PlotConsensus.R(clac.result, chromosome.number, nucleotide.position, sample.index, centromere=NULL,graylevel=0.9)
}

\arguments{
    \item{clac.result}{Result object of function clac.tumorarray.R}
    \item{chromosome.number}{numeric vector . Length should be the same as the row number of \code{NORMAL}. It's the chromosome number of each gene/clone.}
    \item{nucleotide.position}{numeric vector. Length should be the same as the row number of \code{NORMAL}. It's the nucleotide position of each gene/clone.}  
    \item{sample.index}{integer vector. It's the index of the arrays to be included in the consensus plot.}
    \item{centromere}{numeric vector specifying the centromere positions. If missing, the default centromere value of human genome will be used.}
    \item{graylevel}{numeric value between 0 and 1, specifying the gray level for the background scale lines. 0 for black and 1 for white.}
 }  
    
\details{
    \code{clac.PlotConsensus.R} make consensus plot for CLAC result.
 }

\value{
    No return value.
   }

\references{
P. Wang, Y. Kim, J. Pollack, B. Narasimhan and R. Tibshirani, A method for calling gains and losses in array CGH data, Biostatistics (accepted for publication 4/5/2004), available at http://www-stat.stanford.edu/~wp57/CGH-Miner/
}

\author{ Pei Wang}

\keyword{cluster}

\examples{
library(clac)
data(BACarray)
attach(BACarray)

############ prepare the normal reference arrays
NormalResult<-clac.preparenormal.R(DiseaseArray, NormalArray, Normal.Type=rep(0,3), chromosome.number=chromosome, nucleotide.position=nucposition, windowsize=5, targetFDR=0.01, chromosomeOption=FALSE)

############ clac on selected tumor arrays
clac.result<-clac.tumorarray.R(NormalResult, tumorarrayIndex=1:4)

############ Plot for the first arrays
i<-1
clac.PlotSingleArray.R(i, NormalResult, clac.result)
title(main=paste("CLAC Plot for the ", i ,"th BAC array; FDR=", round(clac.result$fdr[i],3), sep=""))

############ consensus plot
clac.PlotConsensus.R(clac.result, chromosome, nucposition,  1:4)
title(main="Consensus Plot for 4 BAC arrays")

############ Plot all arrays
clac.PlotAllArray.R(NormalResult, clac.result)
title(main="Plot for all 4 arrays")
}


\eof
\name{clac.PlotSingleArray.R}
\alias{clac.PlotSingleArray.R}
\title{ A function to plot one single array for CLAC result.}
\description{A function to plot one single array for CLAC result.}
   
\usage{
clac.PlotSingleArray.R(i, NormalResult, clac.result, centromere=NULL, graylevel=0.9)
}
\arguments{
    \item{i}{integer specifying which array to plot}
    \item{NormalResult}{result object of function \code{clac.preparenormal.R}}
    \item{clac.result}{result object of function clac.tumorarray.R}
    \item{centromere}{numeric vector specifying the centromere positions. If missing, the default centromere value of human genome will be used.}
    \item{graylevel}{numeric value between 0 and 1, specifying the gray level for the background scale lines. 0 for black and 1 for white.}
 }  
    
\details{
    \code{clac.PlotSingleArray.R} plot one single array for CLAC result.}

\value{
    No return value.
   }

\references{
P. Wang, Y. Kim, J. Pollack, B. Narasimhan and R. Tibshirani, A method for calling gains and losses in array CGH data, Biostatistics (accepted for publication 4/5/2004), available at http://www-stat.stanford.edu/~wp57/CGH-Miner/
}

\author{ Pei Wang}

\keyword{cluster}

\examples{
library(clac)
data(BACarray)
attach(BACarray)

############ prepare the normal reference arrays
NormalResult<-clac.preparenormal.R(DiseaseArray, NormalArray, Normal.Type=rep(0,3), chromosome.number=chromosome, nucleotide.position=nucposition, windowsize=5, targetFDR=0.01, chromosomeOption=FALSE)

############ clac on selected tumor arrays
clac.result<-clac.tumorarray.R(NormalResult, tumorarrayIndex=1:4)

############ Plot for the first arrays
i<-1
clac.PlotSingleArray.R(i, NormalResult, clac.result)
title(main=paste("CLAC Plot for the ", i ,"th BAC array; FDR=", round(clac.result$fdr[i],3), sep=""))

############ consensus plot
clac.PlotConsensus.R(clac.result, chromosome, nucposition,  1:4)
title(main="Consensus Plot for 4 BAC arrays")

############ Plot all arrays
clac.PlotAllArray.R(NormalResult, clac.result)
title(main="Plot for all 4 arrays")
}

\eof
\name{clac.preparenormal.R}
\alias{clac.preparenormal.R}
\title{ A function to prepare normal reference in CLAC(Cluster Along Chromosome) Analysis}
\description{
CLAC is a method for calling gains and losses in CGH array data.
 This function is to prepare normal references in CLAC(Cluster Along Chromosome) Analysis}
   
\usage{
clac.preparenormal.R(CANCER, NORMAL, Normal.Type, chromosome.number, nucleotide.position, windowsize=5, targetFDR=0.01, chromosomeOption=FALSE, centromere=NULL)
}

\arguments{
    \item{CANCER}{data matrix. It's the result of a group of CGH experiments, which are the target disease arrays to analysis. Each column corresponds to one sample (one target array), and each row corresponds to one gene/clone. The (i, j) entry should be the log fluorescence ratio of the ith gene/clone in the jth sample. Missing value should be coded as either NA or 999.}
    \item{NORMAL}{data matrix. It's also the result of a group of CGH experiment. But these results are from normal reference arrays. Again, each column corresponds to one sample, and each row corresponds to one gene/clone. Missing value should be coded as either NA or 999.}
    \item{Normal.Type}{a vector specifying the normal array type. Length should be the same as the column number of \code{NORMAL}. Code 0 for normal reference arrays from the same gender hybridization, while 1 for arrays from opposite gender hybridization. }
    \item{chromosome.number}{numeric vector . Length should be the same as the row number of \code{NORMAL}. It's the chromosome number of each gene/clone.}
    \item{nucleotide.position}{numeric vector. Length should be the same as the row number of \code{NORMAL}. It's the nucleotide position of each gene/clone.}  
    \item{windowsize}{numeric value, specifying the window size to carry out the average smooth.}
    \item{targetFDR}{numeric value between 0 and 1, specifying the desired fianl FDR for CLAC analysis.}
    \item{chromosomeOption}{a boolean variable. If False, the chromosome arms will be considered seperately. If true, two chormosome arms of one chromosome would be dealed together.}
    \item{centromere}{numeric vector specifying the centromere positions. If missing, the default centromere value of human genome will be used.}
}  
    
\details{
    \code{clac.preparenormal.R} builds cluster trees on normal reference arrays, the result is reported to the next step of CLAC analysis.}

\value{
    A list with components
    \item{normal.result}{An object containing the information about the normal reference arrays.}
    \item{CANCER.sm}{The result of average smooth for data matrix CANCER}
    \item{NORMAL.sm}{The result of average smooth for data matrix NORMAL}
   }

\references{
P. Wang, Y. Kim, J. Pollack, B. Narasimhan and R. Tibshirani, A method for calling gains and losses in array CGH data, Biostatistics (accepted for publication 4/5/2004), available at http://www-stat.stanford.edu/~wp57/CGH-Miner/
}

\author{ Pei Wang}

\keyword{cluster}

\examples{
library(clac)
data(BACarray)
attach(BACarray)

############ prepare the normal reference arrays
NormalResult<-clac.preparenormal.R(DiseaseArray, NormalArray, Normal.Type=rep(0,3), chromosome.number=chromosome, nucleotide.position=nucposition, windowsize=5, targetFDR=0.01, chromosomeOption=FALSE)

############ clac on selected tumor arrays
clac.result<-clac.tumorarray.R(NormalResult, tumorarrayIndex=1:4)

############ Plot for the first arrays
i<-1
clac.PlotSingleArray.R(i, NormalResult, clac.result)
title(main=paste("CLAC Plot for the ", i ,"th BAC array; FDR=", round(clac.result$fdr[i],3), sep=""))

############ consensus plot
clac.PlotConsensus.R(clac.result, chromosome, nucposition,  1:4)
title(main="Consensus Plot for 4 BAC arrays")

############ Plot all arrays
clac.PlotAllArray.R(NormalResult, clac.result)
title(main="Plot for all 4 arrays")
}

\eof
\name{clac.tumorarray.R}
\alias{clac.tumorarray.R}
\title{A function to do CLAC(Cluster Along Chromosome) Analysis}
\description{A function to do CLAC(Cluster Along Chromosome) Analysis}
   
\usage{
clac.tumorarray.R(NormalResult, tumorarrayIndex)}

\arguments{
    \item{NormalResult}{result object from function \code{clac.preparenormal.R} in package \code{clac}.}
    \item{tumorarrayIndex}{a vector serving as a subscript index to take out a subset of the disease arrays for analysis}
}
        
\details{
    \code{clac.tumorarray.R} do CLAC analysis on selected arrays.
}

\value{
    A list with components
    \item{RegionMean}{data matrix reporting the CLAC result. It has the same dimension as the original input data matrix \code{CANCER} of function \code{clac.preparenormal.R}. For each entry of the matrix, 0 is reported if this genes/clone is not being called to have any copy number alteration, otherwise the amplificaiton/deletion region mean of the genes/clone is reported.}
    \item{fdr}{numeric vector reporting the result FDR for each target disease array.}
       }

\references{
P. Wang, Y. Kim, J. Pollack, B. Narasimhan and R. Tibshirani, A method for calling gains and losses in array CGH data, Biostatistics (accepted for publication 4/5/2004), available at http://www-stat.stanford.edu/~wp57/CGH-Miner/
}

\author{ Pei Wang}

\keyword{cluster}

\examples{
library(clac)
data(BACarray)
attach(BACarray)

############ prepare the normal reference arrays
NormalResult<-clac.preparenormal.R(DiseaseArray, NormalArray, Normal.Type=rep(0,3), chromosome.number=chromosome, nucleotide.position=nucposition, windowsize=5, targetFDR=0.01, chromosomeOption=FALSE)

############ clac on selected tumor arrays
clac.result<-clac.tumorarray.R(NormalResult, tumorarrayIndex=1:4)

############ Plot for the first arrays
i<-1
clac.PlotSingleArray.R(i, NormalResult, clac.result)
title(main=paste("CLAC Plot for the ", i ,"th BAC array; FDR=", round(clac.result$fdr[i],3), sep=""))

############ consensus plot
clac.PlotConsensus.R(clac.result, chromosome, nucposition,  1:4)
title(main="Consensus Plot for 4 BAC arrays")

############ Plot all arrays
clac.PlotAllArray.R(NormalResult, clac.result)
title(main="Plot for all 4 arrays")
}


\eof
